Jido.AI.Reasoning.ChainOfDraft.Strategy (Jido AI v2.1.0)

Chain-of-Draft strategy implemented as a thin wrapper over delegated CoT runtime.

CoD reuses CoT worker orchestration (ai.cot.worker.*) and only changes the public query signal/action surface plus default prompt contract.

Summary

Functions

Returns the conclusion from the agent's current state.

Returns the raw LLM response from the agent's current state.

Returns the extracted reasoning steps from the agent's current state.

Returns the legacy action atom for handling streaming LLM partial tokens.

Returns the legacy action atom for handling LLM results.

Returns the action atom for handling request rejection events.

Returns the action atom for starting a CoD reasoning session.

Functions

get_conclusion(agent)

@spec get_conclusion(Jido.Agent.t()) :: String.t() | nil

Returns the conclusion from the agent's current state.

get_raw_response(agent)

@spec get_raw_response(Jido.Agent.t()) :: String.t() | nil

Returns the raw LLM response from the agent's current state.

get_steps(agent)

Returns the extracted reasoning steps from the agent's current state.

llm_partial_action()

@spec llm_partial_action() :: :cod_llm_partial

Returns the legacy action atom for handling streaming LLM partial tokens.

llm_result_action()

@spec llm_result_action() :: :cod_llm_result

Returns the legacy action atom for handling LLM results.

request_error_action()

@spec request_error_action() :: :cod_request_error

Returns the action atom for handling request rejection events.

start_action()

@spec start_action() :: :cod_start

Returns the action atom for starting a CoD reasoning session.